@@ -12,7 +12,7 @@ sys.path.insert(0, os.path.abspath("../../"))
 project = "python-terminusgps"
 copyright = "2025, Terminus GPS, LLC"
 author = "Terminus GPS, LLC"
-release = "43.3.0"
+release = "44.0.0"
 
 # -- General configuration ---------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration
@@ -28,8 +28,8 @@ extensions = [
 intersphinx_mapping = {
     "python": ("https://docs.python.org/3/", None),
     "django": (
-        "http://docs.djangoproject.com/en/stable/",
-        "http://docs.djangoproject.com/en/stable/_objects/",
+        "https://docs.djangoproject.com/en/5.2/",
+        "https://docs.djangoproject.com/en/5.2/objects.inv",
     ),
 }
 
@@ -40,7 +40,9 @@ exclude_patterns = []
 # -- Options for HTML output -------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output
 
+autodoc_member_order = "groupwise"
 html_theme = "sphinxawesome_theme"
 pygments_style = "sas"
 pygments_style_dark = "lightbulb"
 html_static_path = ["_static"]
+graphviz_dot = "/usr/bin/dot"
